﻿local addon, ns = ...
local BarTexture = CreateFrame("frame")
local LSM = LibStub("LibSharedMedia-3.0")

local defaultTexture = LSM:GetDefault("statusbar")
local defaultFrames = {
   ["PlayerFrame"] = true,
   ["TargetFrame"] = true,
   ["FocusFrame"] = true,
   
}
local defaultBars = {
   ["Health"] = true,
   ["Mana"] = true
}
function BarTexture:UpdateBars()
   for k,v in pairs(BarTextureFrames) do
      _G[k].healthbar:SetStatusBarTexture(LSM:Fetch("statusbar", defaultTexture))
      _G[k].manabar:SetStatusBarTexture(LSM:Fetch("statusbar", defaultTexture))
   end
   if BarTextureBars["Health"] then
      for k,v in pairs(BarTextureFrames) do
         if(v == true) then
            _G[k].healthbar:SetStatusBarTexture(LSM:Fetch("statusbar", BarTextureTexture))
         else 
            _G[k].healthbar:SetStatusBarTexture(LSM:Fetch("statusbar", defaultTexture))
         end
      end
   end
   if BarTextureBars["Mana"] then
      for k,v in pairs(BarTextureFrames) do
         if(v == true) then
            _G[k].manabar:SetStatusBarTexture(LSM:Fetch("statusbar", BarTextureTexture))
         else 
            _G[k].manabar:SetStatusBarTexture(LSM:Fetch("statusbar", defaultTexture))
         end
      end
   end
end

SLASH_BARTEXTURE1, SLASH_BARTEXTURE2 = '/bartexture', '/bt';
function SlashCmdList.BARTEXTURE(msg, editbox)
   local command, option = msg:match("^(%S*)%s*(.-)$");
   if command == "list" then
      if option == "textures" then
         print("List of available textures:")
         table.foreach(LSM:List("statusbar"), function(k,v) print(v) end)
      elseif option == "frames" then
         print("List of frames:")
         table.foreach(BarTextureFrames, function(k,v) print(k .. " = " .. (v and "\124cFF00FF00Enabled\124r" or "\124cFFFF0000Disabled\124r")) end)
      elseif option == "bars" then
         print("List of available bars:")
         table.foreach(BarTextureBars, function(k,v) print(k .. " = " .. (v and "\124cFF00FF00Enabled\124r" or "\124cFFFF0000Disabled\124r")) end)
      end
   elseif command == "toggle" then
      if string.len(option) >=1 then
         if BarTextureFrames[option] ~= nil then
            BarTextureFrames[option] = not BarTextureFrames[option]
            BarTexture:UpdateBars()
            print(option .. ": " .. (BarTextureFrames[option] and "\124cFF00FF00Enabled\124r" or "\124cFFFF0000Disabled\124r"))
         else
            print(option .. " isn't a valid frame.")
         end
      else
         print("Toggle frame on and off")
         
      end
   elseif command == "texture" then
      if string.len(option) >=1 then
         if LSM:List("statusbar") ~= nil then
            BarTextureTexture  = option
            BarTexture:UpdateBars()
         else
            print("Invalid Texture")
         end
      else
         print("Set texture to use on bars")
         print("A list of valid textures can seen by typing /bartexture list textures")
         print("Current Texture: " .. BarTextureTexture)
      end
   elseif command == "bar" then
      if string.len(option) >=1 then
         if BarTextureBars[option] ~= nil then
            BarTextureBars[option] = not BarTextureBars[option]
            BarTexture:UpdateBars()
            print(option .. ": " .. (BarTextureBars[option] and "\124cFF00FF00Enabled\124r" or "\124cFFFF0000Disabled\124r"))
         else
            print("Invalid bar")
         end
      else
         print("Toggle on/off health and mana bar texturing")
         
      end
   else
      print("Bar Texture\n/bt list textures - List available textures\n/bt list frames - List frames and enabled status\n/bt list bars - List bars and status\n/bt texture <texture> - Set texture to use\n/bt toggle <frame> - Toggle on/off customizing texture of the frame\n/bt bar <Health/Mana> - Toggle on/off health and mana bar")
   end
end

function BarTexture:OnEvent(event, name)
   if event == "ADDON_LOADED" and name == addon then
      if BarTextureFrames == nil then
         BarTextureFrames = defaultFrames
      end
      if BarTextureTexture == nil then
         BarTextureTexture = defaultTexture
      end
      if BarTextureBars == nil then
         BarTextureBars = defaultBars
      end
      self:UnregisterEvent("ADDON_LOADED")
   end
   BarTexture:UpdateBars()
end

BarTexture:SetScript("OnEvent", BarTexture.OnEvent)
BarTexture:RegisterEvent("ADDON_LOADED")
BarTexture:RegisterEvent("PLAYER_ENTERING_WORLD")